<?php
/**
 * @package     CSVI
 * @subpackage  HikaShop
 *
 * @author      RolandD Cyber Produksi <contact@rolandd.com>
 * @copyright   Copyright (C) 2006 - 2021 RolandD Cyber Produksi. All rights reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link        https://rolandd.com
 */

defined('_JEXEC') or die;

require_once JPATH_PLUGINS . '/csviaddon/hikashop/com_hikashop/helper/com_hikashop_category.php';

/**
 * The HikaShop category helper class for products.
 *
 * @package     CSVI
 * @subpackage  HikaShop
 * @since       6.0
 */
class Com_HikashopHelperCom_Hikashop_Category_Product extends Com_HikashopHelperCom_Hikashop_Category
{
	/**
	 * CSVI template helper
	 *
	 * @var    CsviHelperTemplate
	 * @since  6.0
	 */
	protected $template = null;

	/**
	 * CSVI log helper
	 *
	 * @var    CsviHelperLog
	 * @since  6.0
	 */
	protected $log = null;

	/**
	 * Constructor.
	 *
	 * @param   JDatabase           $db        Database connector.
	 * @param   CsviHelperTemplate  $template  CSVI template.
	 * @param   CsviHelperLog       $log       CSVI log.
	 *
	 * @throws  CsviException
	 *
	 * @since   4.0
	 */
	public function __construct($db, CsviHelperTemplate $template, CsviHelperLog $log)
	{
		$this->db = $db;
		$this->template = $template;
		$this->log = $log;

		// Load the category separator
		if (is_null($this->categorySeparator))
		{
			$this->categorySeparator = $this->template->get('category_separator', '/');
		}

		// Load the table file
		require_once JPATH_PLUGINS . '/csviaddon/hikashop/com_hikashop/table/category.php';

		// Instantiate the table
		try
		{
			$this->table = new HikashopTableCategory('', '', $db, array('template' => $this->template, 'log' => $this->log));
		}
		catch (Exception $e)
		{
			throw new CsviException(JText::sprintf('COM_CSVI_NO_TABLE_LOADED', 'HikashopTableCategory', $e->getMessage()), 513);
		}
	}
}
